@@ -402,6 +402,8 @@ sig
     (** Whether this method supports media uploads. *)
     supportsSubscription : bool;
     (** Whether this method supports subscriptions. *)
+    useMediaDownloadService : bool;
+    (** Indicates that downloads from this method should use the download service URL (i.e. "/download"). Only applies if the method supports media download. *)
     
   }
   
@@ -419,6 +421,7 @@ sig
   val supportsMediaDownload : (t, bool) GapiLens.t
   val supportsMediaUpload : (t, bool) GapiLens.t
   val supportsSubscription : (t, bool) GapiLens.t
+  val useMediaDownloadService : (t, bool) GapiLens.t
   
   val empty : t
   
@@ -538,9 +541,9 @@ sig
     auth : Auth.t;
     (** Authentication information. *)
     basePath : string;
-    (** [DEPRECATED] The base path for REST requests. *)
+    (** \[DEPRECATED\] The base path for REST requests. *)
     baseUrl : string;
-    (** [DEPRECATED] The base URL for REST requests. *)
+    (** \[DEPRECATED\] The base URL for REST requests. *)
     batchPath : string;
     (** The path for REST batch requests. *)
     canonicalName : string;
@@ -553,6 +556,8 @@ sig
     (** A link to human readable documentation for the API. *)
     etag : string;
     (** The ETag for this response. *)
+    exponentialBackoffDefault : bool;
+    (** Enable exponential backoff for suitable methods in the generated clients. *)
     features : string list;
     (** A list of supported features for this API. *)
     icons : Icons.t;
@@ -591,6 +596,8 @@ sig
     (** The title of this API. *)
     version : string;
     (** The version of this API. *)
+    version_module : bool;
+    (**  *)
     
   }
   
@@ -603,6 +610,7 @@ sig
   val discoveryVersion : (t, string) GapiLens.t
   val documentationLink : (t, string) GapiLens.t
   val etag : (t, string) GapiLens.t
+  val exponentialBackoffDefault : (t, bool) GapiLens.t
   val features : (t, string list) GapiLens.t
   val icons : (t, Icons.t) GapiLens.t
   val id : (t, string) GapiLens.t
@@ -622,6 +630,7 @@ sig
   val servicePath : (t, string) GapiLens.t
   val title : (t, string) GapiLens.t
   val version : (t, string) GapiLens.t
+  val version_module : (t, bool) GapiLens.t
   
   val empty : t
   
